@@ -16,18 +16,14 @@
  */
 package org.apache.qpid.jms;
 
-import static org.junit.jupiter.api.Assertions.assertThrows;
+import jakarta.jms.Destination;
+import jakarta.jms.ExceptionListener;
+import jakarta.jms.JMSException;
+import jakarta.jms.Session;
+import jakarta.jms.Topic;
 
-import javax.jms.Destination;
-import javax.jms.ExceptionListener;
-import javax.jms.JMSException;
-import javax.jms.Session;
-import javax.jms.Topic;
-
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Test Connection methods contracts when state is closed.
@@ -45,91 +41,63 @@ public class JmsConnectionClosedTest extends JmsConnectionTestSupport {
     }
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
         connection = createConnection();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testGetClientIdFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.getClientID();
-        });
+        connection.getClientID();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testSetClientIdFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.setClientID("test");
-        });
+        connection.setClientID("test");
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testGetMetaData() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.getMetaData();
-        });
+        connection.getMetaData();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testGetExceptionListener() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.getExceptionListener();
-        });
+        connection.getExceptionListener();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testSetExceptionListener() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.setExceptionListener(new ExceptionListener() {
-                @Override
-                public void onException(JMSException exception) {
-                }
-            });
+        connection.setExceptionListener(new ExceptionListener() {
+            @Override
+            public void onException(JMSException exception) {
+            }
         });
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testStartFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.start();
-        });
+        connection.start();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testStopFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.stop();
-        });
+        connection.stop();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000)
     public void testClose() throws Exception {
         connection.close();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testCreateConnectionConsumerFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.createConnectionConsumer(destination, "", null, 1);
-        });
+        connection.createConnectionConsumer(destination, "", null, 1);
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=JMSException.class)
     public void testCreateDurableConnectionConsumerFails() throws Exception {
-        assertThrows(JMSException.class, () -> {
-            connection.createDurableConnectionConsumer((Topic) destination, "id", "", null, 1);
-        });
+        connection.createDurableConnectionConsumer((Topic) destination, "id", "", null, 1);
     }
 }
