@@ -16,19 +16,15 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.jupiter.api.Assertions.assertThrows;
-
-import javax.jms.Queue;
-import javax.jms.QueueConnection;
-import javax.jms.QueueReceiver;
-import javax.jms.QueueSession;
-import javax.jms.Session;
+import jakarta.jms.Queue;
+import jakarta.jms.QueueConnection;
+import jakarta.jms.QueueReceiver;
+import jakarta.jms.QueueSession;
+import jakarta.jms.Session;
 
 import org.apache.qpid.jms.JmsConnectionTestSupport;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.TestInfo;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Before;
+import org.junit.Test;
 
 /**
  * Tests QueueReceiver method contracts after the QueueReceiver is closed.
@@ -40,39 +36,30 @@ public class JmsQueueReceiverClosedTest extends JmsConnectionTestSupport {
     protected void createTestResources() throws Exception {
         connection = createQueueConnectionToMockProvider();
         QueueSession session = ((QueueConnection) connection).createQueueSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue destination = session.createQueue(_testMethodName);
+        Queue destination = session.createQueue(_testName.getMethodName());
         receiver = session.createReceiver(destination);
         receiver.close();
     }
 
     @Override
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        super.setUp(testInfo);
+    @Before
+    public void setUp() throws Exception {
+        super.setUp();
         createTestResources();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetMessageListenerFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            receiver.getMessageListener();
-        });
+        receiver.getMessageListener();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetMessageSelectorFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            receiver.getMessageSelector();
-        });
+        receiver.getMessageSelector();
     }
 
-    @Test
-    @Timeout(30)
+    @Test(timeout=30000, expected=jakarta.jms.IllegalStateException.class)
     public void testGetTopicFails() throws Exception {
-        assertThrows(javax.jms.IllegalStateException.class, () -> {
-            receiver.getQueue();
-        });
+        receiver.getQueue();
     }
 }
