@@ -19,11 +19,11 @@
 package org.apache.qpid.jms.integration;
 
 import static org.hamcrest.Matchers.notNullValue;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.io.ByteArrayOutputStream;
 import java.io.ObjectOutputStream;
@@ -31,14 +31,14 @@ import java.util.Arrays;
 import java.util.LinkedHashMap;
 import java.util.Map;
 
-import javax.jms.IllegalStateRuntimeException;
-import javax.jms.JMSConsumer;
-import javax.jms.JMSContext;
-import javax.jms.JMSRuntimeException;
-import javax.jms.Message;
-import javax.jms.MessageFormatRuntimeException;
-import javax.jms.MessageListener;
-import javax.jms.Queue;
+import jakarta.jms.IllegalStateRuntimeException;
+import jakarta.jms.JMSConsumer;
+import jakarta.jms.JMSContext;
+import jakarta.jms.JMSRuntimeException;
+import jakarta.jms.Message;
+import jakarta.jms.MessageFormatRuntimeException;
+import jakarta.jms.MessageListener;
+import jakarta.jms.Queue;
 
 import org.apache.qpid.jms.provider.amqp.message.AmqpMessageSupport;
 import org.apache.qpid.jms.test.QpidJmsTestCase;
@@ -52,8 +52,7 @@ import org.apache.qpid.jms.test.testpeer.describedtypes.sections.PropertiesDescr
 import org.apache.qpid.proton.amqp.Binary;
 import org.apache.qpid.proton.amqp.DescribedType;
 import org.apache.qpid.proton.amqp.UnsignedInteger;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -63,8 +62,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
 
     private final IntegrationTestFixture testFixture = new IntegrationTestFixture();
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testCreateConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -84,8 +82,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testRemotelyCloseJMSConsumer() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -102,7 +99,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
 
             // Verify the consumer gets marked closed
             testPeer.waitForAllHandlersToComplete(1000);
-            assertTrue(Wait.waitFor(new Wait.Condition() {
+            assertTrue("JMSConsumer never closed.", Wait.waitFor(new Wait.Condition() {
                 @Override
                 public boolean isSatisfied() throws Exception {
                     try {
@@ -112,7 +109,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
                     }
                     return false;
                 }
-            }, 10000, 10), "JMSConsumer never closed.");
+            }, 10000, 10));
 
             // Try closing it explicitly, should effectively no-op in client.
             // The test peer will throw during close if it sends anything.
@@ -126,8 +123,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveMessageWithReceiveZeroTimeout() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -145,7 +141,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
             JMSConsumer messageConsumer = context.createConsumer(queue);
             Message receivedMessage = messageConsumer.receive(0);
 
-            assertNotNull(receivedMessage, "A message should have been recieved");
+            assertNotNull("A message should have been recieved", receivedMessage);
 
             testPeer.expectEnd();
             testPeer.expectClose();
@@ -155,8 +151,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testConsumerReceiveNoWaitThrowsIfConnectionLost() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -186,8 +181,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout=20000)
     public void testNoReceivedMessagesWhenConnectionNotStarted() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -217,8 +211,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testSyncReceiveFailsWhenListenerSet() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -265,8 +258,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyMapMessage() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -328,19 +320,19 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
             Map<String, Object> receivedMap = messageConsumer.receiveBody(Map.class, 3000);
 
             // verify the content is as expected
-            assertNotNull(receivedMap, "Map was not received");
+            assertNotNull("Map was not received", receivedMap);
 
-            assertEquals(myBool, receivedMap.get(myBoolKey), "Unexpected boolean value");
-            assertEquals(myByte, receivedMap.get(myByteKey), "Unexpected byte value");
+            assertEquals("Unexpected boolean value", myBool, receivedMap.get(myBoolKey));
+            assertEquals("Unexpected byte value", myByte, receivedMap.get(myByteKey));
             byte[] readBytes = (byte[]) receivedMap.get(myBytesKey);
-            assertTrue(Arrays.equals(myBytes, readBytes), "Read bytes were not as expected: " + Arrays.toString(readBytes));
-            assertEquals(myChar, receivedMap.get(myCharKey), "Unexpected char value");
-            assertEquals(myDouble, (double) receivedMap.get(myDoubleKey), 0.0, "Unexpected double value");
-            assertEquals(myFloat, (float) receivedMap.get(myFloatKey), 0.0, "Unexpected float value");
-            assertEquals(myInt, receivedMap.get(myIntKey), "Unexpected int value");
-            assertEquals(myLong, receivedMap.get(myLongKey), "Unexpected long value");
-            assertEquals(myShort, receivedMap.get(myShortKey), "Unexpected short value");
-            assertEquals(myString, receivedMap.get(myStringKey), "Unexpected UTF value");
+            assertTrue("Read bytes were not as expected: " + Arrays.toString(readBytes), Arrays.equals(myBytes, readBytes));
+            assertEquals("Unexpected char value", myChar, receivedMap.get(myCharKey));
+            assertEquals("Unexpected double value", myDouble, (double) receivedMap.get(myDoubleKey), 0.0);
+            assertEquals("Unexpected float value", myFloat, (float) receivedMap.get(myFloatKey), 0.0);
+            assertEquals("Unexpected int value", myInt, receivedMap.get(myIntKey));
+            assertEquals("Unexpected long value", myLong, receivedMap.get(myLongKey));
+            assertEquals("Unexpected short value", myShort, receivedMap.get(myShortKey));
+            assertEquals("Unexpected UTF value", myString, receivedMap.get(myStringKey));
 
             context.close();
 
@@ -348,8 +340,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyTextMessage() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -379,8 +370,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyObjectMessage() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -424,8 +414,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyBytesMessage() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
@@ -464,20 +453,17 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyFailsDoesNotAcceptMessageAutoAck() throws Exception {
         doTestReceiveBodyFailsDoesNotAcceptMessage(JMSContext.AUTO_ACKNOWLEDGE);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyFailsDoesNotAcceptMessageDupsOk() throws Exception {
         doTestReceiveBodyFailsDoesNotAcceptMessage(JMSContext.DUPS_OK_ACKNOWLEDGE);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyFailsDoesNotAcceptMessageClientAck() throws Exception {
         doTestReceiveBodyFailsDoesNotAcceptMessage(JMSContext.CLIENT_ACKNOWLEDGE);
     }
@@ -511,20 +497,17 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyFailsThenAcceptsOnSuccessfullyNextCallAutoAck() throws Exception {
         doTestReceiveBodyFailsDoesNotAcceptMessage(JMSContext.AUTO_ACKNOWLEDGE);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyFailsThenAcceptsOnSuccessfullyNextCallDupsOk() throws Exception {
         doTestReceiveBodyFailsDoesNotAcceptMessage(JMSContext.DUPS_OK_ACKNOWLEDGE);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyFailsThenGetNullOnNextAttemptClientAck() throws Exception {
         doTestReceiveBodyFailsDoesNotAcceptMessage(JMSContext.CLIENT_ACKNOWLEDGE);
     }
@@ -578,8 +561,7 @@ public class JMSConsumerIntegrationTest extends QpidJmsTestCase {
         }
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testReceiveBodyBytesMessageFailsWhenWrongTypeRequested() throws Exception {
         try (TestAmqpPeer testPeer = new TestAmqpPeer();) {
             JMSContext context = testFixture.createJMSContext(testPeer);
