@@ -20,26 +20,26 @@ import static org.apache.qpid.jms.provider.amqp.AmqpSupport.ANONYMOUS_RELAY;
 import static org.hamcrest.Matchers.arrayContaining;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.nullValue;
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.CompletionListener;
-import javax.jms.Connection;
-import javax.jms.Destination;
-import javax.jms.Message;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TemporaryQueue;
-import javax.jms.TemporaryTopic;
-import javax.jms.TextMessage;
-import javax.jms.Topic;
+import jakarta.jms.CompletionListener;
+import jakarta.jms.Connection;
+import jakarta.jms.Destination;
+import jakarta.jms.Message;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TemporaryQueue;
+import jakarta.jms.TemporaryTopic;
+import jakarta.jms.TextMessage;
+import jakarta.jms.Topic;
 
 import org.apache.qpid.jms.test.QpidJmsTestCase;
 import org.apache.qpid.jms.test.testpeer.ListDescribedType;
@@ -55,8 +55,7 @@ import org.apache.qpid.proton.amqp.Binary;
 import org.apache.qpid.proton.amqp.Symbol;
 import org.apache.qpid.proton.amqp.transaction.TxnCapability;
 import org.hamcrest.Matcher;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -73,57 +72,49 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleAll option ---------------------------------//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllSendToTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllSendToQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllSendToTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllSendToTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, TemporaryQueue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllAnonymousSendToTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllAnonymousSendToQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllAnonymousSendToTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleAllAnonymousSendToTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, TemporaryQueue.class);
@@ -131,57 +122,49 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleProducers option ---------------------------------//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, TemporaryQueue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersAnonymousTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersAnonymousQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersAnonymousTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleProducersAnonymousTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, true, true, TemporaryQueue.class);
@@ -189,57 +172,49 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleTopicProducers option ---------------------------------//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, TemporaryQueue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersAnonymousTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersAnonymousQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, false, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersAnonymousTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTopicProducersAnonymousTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTopicProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, false, TemporaryQueue.class);
@@ -247,57 +222,49 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleQueueProducers option ---------------------------------//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, true, true, TemporaryQueue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersAnonymousTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, false, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersAnonymousQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersAnonymousTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, false, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleQueueProducersAnonymousTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleQueueProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, true, false, true, TemporaryQueue.class);
@@ -305,57 +272,49 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleTransactedProducers option ---------------------------------//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, true, false, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, true, false, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersTempTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, true, false, true, true, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersTempQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, true, false, true, true, TemporaryQueue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersTopicNoTX() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersQueueNoTX() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersTempTopicNoTX() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, TemporaryTopic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testJmsPresettlePolicyPresettleTransactedProducersTempQueueNoTX() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleTransactedProducers=true";
         doTestProducerWithPresettleOptions(presettleConfig, false, false, false, false, TemporaryQueue.class);
@@ -476,29 +435,25 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleAll with asynchronous completion -----------//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionPresettleAllSendToTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, false, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionPresettleAllSendToQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, false, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testsyncCompletionPresettleAllAnonymousSendToTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, true, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testsyncCompletionPresettleAllAnonymousSendToQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleAll=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, true, true, true, Queue.class);
@@ -506,29 +461,25 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
     //----- Test the jms.presettleProducers with asynchronous completion -----//
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionPresettleProducersTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, false, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionPresettleProducersQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, false, true, true, Queue.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionPresettleProducersAnonymousTopic() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, true, true, true, Topic.class);
     }
 
-    @Test
-    @Timeout(20)
+    @Test(timeout = 20000)
     public void testAsyncCompletionPresettleProducersAnonymousQueue() throws Exception {
         String presettleConfig = "?jms.presettlePolicy.presettleProducers=true";
         doTestAsyncCompletionProducerWithPresettleOptions(presettleConfig, false, true, true, true, Queue.class);
@@ -642,7 +593,7 @@ public class PresettledProducerIntegrationTest extends QpidJmsTestCase {
 
             testPeer.expectClose();
 
-            assertTrue(listener.awaitCompletion(2000, TimeUnit.SECONDS), "Did not get async callback");
+            assertTrue("Did not get async callback", listener.awaitCompletion(2000, TimeUnit.SECONDS));
             assertNull(listener.exception);
             assertNotNull(listener.message);
             assertTrue(listener.message instanceof TextMessage);
