@@ -33,11 +33,13 @@ import java.util.Deque;
 import java.util.Map;
 import java.util.function.Function;
 
-import javax.jms.JMSSecurityRuntimeException;
 import javax.security.sasl.SaslException;
 
+import org.apache.qpid.jms.provider.exceptions.ProviderConnectionSecuritySaslException;
 import org.apache.qpid.jms.sasl.Mechanism;
+import org.apache.qpid.jms.sasl.SaslSecurityRuntimeException;
 import org.apache.qpid.proton.engine.Sasl;
+import org.apache.qpid.proton.engine.Sasl.SaslOutcome;
 import org.apache.qpid.proton.engine.Sasl.SaslState;
 import org.apache.qpid.proton.engine.Transport;
 import org.junit.Before;
@@ -77,7 +79,7 @@ public class AmqpSaslAuthenticatorTest {
     @Test
     public void testNoSaslMechanismAgreed() throws Exception {
         Function<String[], Mechanism> mechanismFunction = mechanismName -> {
-            throw new JMSSecurityRuntimeException("reasons");
+            throw new SaslSecurityRuntimeException("reasons");
         };
 
         AmqpSaslAuthenticator authenticator = new AmqpSaslAuthenticator(mechanismFunction);
@@ -137,12 +139,34 @@ public class AmqpSaslAuthenticatorTest {
         verifySaslMockReceived(sasl, INITIAL_RESPONSE);
 
         when(sasl.getState()).thenReturn(SaslState.PN_SASL_FAIL);
+        when(sasl.getOutcome()).thenReturn(SaslOutcome.PN_SASL_AUTH);
         authenticator.handleSaslOutcome(sasl, transport);
 
         assertTrue(authenticator.isComplete());
         assertFalse(authenticator.wasSuccessful());
         assertNotNull(authenticator.getFailureCause());
         assertTrue(authenticator.getFailureCause().getMessage().contains("Client failed to authenticate"));
+        assertFalse(authenticator.getFailureCause().getMessage().contains("due to temporary system error"));
+    }
+
+    @Test
+    public void testPeerSignalsAuthenticationSysTemp() throws Exception {
+        Mechanism mechanism = new TestSaslMechanism(INITIAL_RESPONSE);
+        AmqpSaslAuthenticator authenticator = new AmqpSaslAuthenticator(mechanismName -> mechanism);
+
+        authenticator.handleSaslMechanisms(sasl, transport);
+        verifySaslMockReceived(sasl, INITIAL_RESPONSE);
+
+        when(sasl.getState()).thenReturn(SaslState.PN_SASL_FAIL);
+        when(sasl.getOutcome()).thenReturn(SaslOutcome.PN_SASL_TEMP);
+        authenticator.handleSaslOutcome(sasl, transport);
+
+        assertTrue(authenticator.isComplete());
+        assertFalse(authenticator.wasSuccessful());
+        assertNotNull(authenticator.getFailureCause());
+        assertTrue(authenticator.getFailureCause() instanceof ProviderConnectionSecuritySaslException);
+        assertTrue(authenticator.getFailureCause().getMessage().contains("Client failed to authenticate"));
+        assertTrue(authenticator.getFailureCause().getMessage().contains("due to temporary system error"));
     }
 
     @Test
@@ -171,6 +195,22 @@ public class AmqpSaslAuthenticatorTest {
         assertTrue(authenticator.getFailureCause().getMessage().contains("SASL exchange not completed"));
     }
 
+    @Test
+    public void testEmptyChallengeIsProcessedForResponse() throws Exception {
+        Mechanism mechanism = new TestSaslMechanism(INITIAL_RESPONSE,
+                                                    EMPTY_BYTES, EMPTY_BYTES);
+        AmqpSaslAuthenticator authenticator = new AmqpSaslAuthenticator(mechanismName -> mechanism);
+
+        when(sasl.getState()).thenReturn(SaslState.PN_SASL_IDLE);
+        authenticator.handleSaslMechanisms(sasl, transport);
+        verifySaslMockReceived(sasl, INITIAL_RESPONSE);
+
+        when(sasl.getState()).thenReturn(SaslState.PN_SASL_STEP);
+        configureSaslMockToProduce(sasl, EMPTY_BYTES);
+        authenticator.handleSaslChallenge(sasl, transport);
+        verifySaslMockReceived(sasl, EMPTY_BYTES);
+    }
+
     private void verifySaslMockReceived(final Sasl sasl, final byte[] response) {
         verify(sasl).send(response, 0, response.length);
     }
