@@ -16,25 +16,25 @@
  */
 package org.apache.qpid.jms.consumer;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
 
 import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import javax.jms.Connection;
-import javax.jms.DeliveryMode;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageListener;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TextMessage;
-import javax.jms.Topic;
+import jakarta.jms.Connection;
+import jakarta.jms.DeliveryMode;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageListener;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TextMessage;
+import jakarta.jms.Topic;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.activemq.broker.jmx.TopicViewMBean;
@@ -42,8 +42,7 @@ import org.apache.qpid.jms.JmsMessageAvailableListener;
 import org.apache.qpid.jms.JmsMessageConsumer;
 import org.apache.qpid.jms.support.AmqpTestSupport;
 import org.apache.qpid.jms.support.Wait;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -59,77 +58,73 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         return true;
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCreateMessageConsumer() throws Exception {
         connection = createAmqpConnection();
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         session.createConsumer(queue);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testSyncConsumeFromQueue() throws Exception {
         connection = createAmqpConnection();
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageConsumer consumer = session.createConsumer(queue);
 
         sendToAmqQueue(1);
 
-        final QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        final QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(1, proxy.getQueueSize());
 
-        assertNotNull(consumer.receive(3000), "Failed to receive any message.");
+        assertNotNull("Failed to receive any message.", consumer.receive(3000));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Queued message not consumed.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 0;
             }
-        }), "Queued message not consumed.");
+        }));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testSyncConsumeFromTopic() throws Exception {
         connection = createAmqpConnection();
         connection.start();
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Topic topic = session.createTopic(testMethodName);
+        Topic topic = session.createTopic(name.getMethodName());
         MessageConsumer consumer = session.createConsumer(topic);
 
         sendToAmqTopic(1);
 
-        final TopicViewMBean proxy = getProxyToTopic(testMethodName);
+        final TopicViewMBean proxy = getProxyToTopic(name.getMethodName());
         assertEquals(1, proxy.getEnqueueCount());
 
-        assertNotNull(consumer.receive(3000), "Failed to receive any message.");
+        assertNotNull("Failed to receive any message.", consumer.receive(3000));
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Published message not consumed.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 0;
             }
-        }), "Published message not consumed.");
+        }));
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testMessageAvailableConsumer() throws Exception {
         connection = createAmqpConnection();
         connection.start();
@@ -139,7 +134,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
 
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         assertNotNull(session);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageConsumer consumer = session.createConsumer(queue);
         ((JmsMessageConsumer) consumer).setAvailableListener(new JmsMessageAvailableListener() {
 
@@ -151,29 +146,29 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
 
         sendToAmqQueue(MSG_COUNT);
 
-        final QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        final QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(MSG_COUNT, proxy.getQueueSize());
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Listener not notified of correct number of messages.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return available.get() == MSG_COUNT;
             }
-        }), "Listener not notified of correct number of messages.");
+        }));
 
         // All should be immediately ready for consume.
         for (int i = 0; i < MSG_COUNT; ++i) {
             assertNotNull(consumer.receiveNoWait());
         }
 
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        assertTrue("Queued message not consumed.", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 0;
             }
-        }), "Queued message not consumed.");
+        }));
     }
 
     /**
@@ -185,15 +180,14 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
      *
      * @throws Exception on error found during test run.
      */
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testConsumerReceiveBeforeMessageDispatched() throws Exception {
         final Connection connection = createAmqpConnection();
         this.connection = connection;
         connection.start();
 
         final Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        final Queue queue = session.createQueue(testMethodName);
+        final Queue queue = session.createQueue(name.getMethodName());
 
         Thread t = new Thread() {
             @Override
@@ -213,8 +207,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertNotNull(msg);
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testAsynchronousMessageConsumption() throws Exception {
         final int msgCount = 4;
         final Connection connection = createAmqpConnection();
@@ -224,7 +217,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
 
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue destination = session.createQueue(testMethodName);
+        Queue destination = session.createQueue(name.getMethodName());
         MessageConsumer consumer = session.createConsumer(destination);
 
         consumer.setMessageListener(new MessageListener() {
@@ -243,47 +236,48 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         assertEquals(msgCount, counter.get());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testMessagesAreAckedAMQProducer() throws Exception {
         int messagesSent = 3;
         assertTrue(brokerService.isPersistent());
 
-        connection = createActiveMQConnection();
-        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
-        MessageProducer p = session.createProducer(queue);
-        TextMessage message = null;
-        for (int i=0; i < messagesSent; i++) {
-            message = session.createTextMessage();
-            String messageText = "Hello " + i + " sent at " + new java.util.Date().toString();
-            message.setText(messageText);
-            LOG.debug(">>>> Sent [{}]", messageText);
-            p.send(message);
+        javax.jms.Connection conn = createActiveMQConnection();
+        try {
+            javax.jms.Session session = conn.createSession(false, Session.AUTO_ACKNOWLEDGE);
+            javax.jms.Queue queue = session.createQueue(name.getMethodName());
+            javax.jms.MessageProducer p = session.createProducer(queue);
+            javax.jms.TextMessage message = null;
+            for (int i = 0; i < messagesSent; i++) {
+                message = session.createTextMessage();
+                String messageText = "Hello " + i + " sent at " + new java.util.Date().toString();
+                message.setText(messageText);
+                LOG.debug(">>>> Sent [{}]", messageText);
+                p.send(message);
+            }
+        } finally {
+            conn.close();
         }
-        connection.close();
 
         // After the first restart we should get all messages sent above
         restartPrimaryBroker();
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(messagesSent, proxy.getQueueSize());
         int messagesReceived = readAllMessages();
         assertEquals(messagesSent, messagesReceived);
 
         // This time there should be no messages on this queue
         restartPrimaryBroker();
-        proxy = getProxyToQueue(testMethodName);
+        proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testMessagesAreAckedAMQPProducer() throws Exception {
         int messagesSent = 3;
 
         connection = createAmqpConnection();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
         producer.setDeliveryMode(DeliveryMode.PERSISTENT);
         TextMessage message = null;
@@ -299,14 +293,14 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
 
         // After the first restart we should get all messages sent above
         restartPrimaryBroker();
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(messagesSent, proxy.getQueueSize());
         int messagesReceived = readAllMessages();
         assertEquals(messagesSent, messagesReceived);
 
         // This time there should be no messages on this queue
         restartPrimaryBroker();
-        proxy = getProxyToQueue(testMethodName);
+        proxy = getProxyToQueue(name.getMethodName());
         assertEquals(0, proxy.getQueueSize());
     }
 
@@ -319,7 +313,7 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         connection.start();
         try {
             Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-            Queue queue = session.createQueue(testMethodName);
+            Queue queue = session.createQueue(name.getMethodName());
             int messagesReceived = 0;
             MessageConsumer consumer;
 
@@ -346,13 +340,12 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
         }
     }
 
-    @Test
-    @Timeout(30)
-    public void testSelectors() throws Exception {
+    @Test(timeout=30000)
+    public void testSelectors() throws Exception{
         connection = createAmqpConnection();
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer p = session.createProducer(queue);
 
         TextMessage message = session.createTextMessage();
@@ -365,24 +358,23 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
 
         p.close();
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(2, proxy.getQueueSize());
 
         MessageConsumer consumer = session.createConsumer(queue, "JMSPriority > 8");
         Message msg = consumer.receive(5000);
-        assertNotNull(msg, "No message was recieved");
+        assertNotNull("No message was recieved", msg);
         assertTrue(msg instanceof TextMessage);
         assertEquals("hello + 9", ((TextMessage) msg).getText());
         assertNull(consumer.receive(1000));
     }
 
-    @Test
-    @Timeout(45)
+    @Test(timeout=45000)
     public void testSelectorsWithJMSType() throws Exception {
         connection = createAmqpConnection();
         connection.start();
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageProducer producer = session.createProducer(queue);
 
         TextMessage message = session.createTextMessage();
@@ -397,20 +389,20 @@ public class JmsMessageConsumerTest extends AmqpTestSupport {
 
         producer.close();
 
-        final QueueViewMBean proxy = getProxyToQueue(testMethodName);
-        assertTrue(Wait.waitFor(new Wait.Condition() {
+        final QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
+        assertTrue("Queue did not get all expected messages", Wait.waitFor(new Wait.Condition() {
 
             @Override
             public boolean isSatisfied() throws Exception {
                 return proxy.getQueueSize() == 2;
             }
-        }), "Queue did not get all expected messages");
+        }));
 
         MessageConsumer consumer = session.createConsumer(queue, "JMSType = '" + type + "'");
         Message msg = consumer.receive(5000);
-        assertNotNull(msg, "No message was recieved");
+        assertNotNull("No message was recieved", msg);
         assertTrue(msg instanceof TextMessage);
-        assertEquals(type, msg.getJMSType(), "Unexpected JMSType value");
-        assertEquals("text + type", ((TextMessage) msg).getText(), "Unexpected message content");
+        assertEquals("Unexpected JMSType value", type, msg.getJMSType());
+        assertEquals("Unexpected message content", "text + type", ((TextMessage) msg).getText());
     }
 }
