@@ -27,15 +27,12 @@ import java.util.Set;
 import java.util.Vector;
 import java.util.concurrent.TimeUnit;
 
-import javax.jms.Connection;
-import javax.jms.ConnectionFactory;
-import javax.jms.Destination;
-import javax.jms.JMSException;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TextMessage;
-import javax.jms.Topic;
+import jakarta.jms.Connection;
+import jakarta.jms.Destination;
+import jakarta.jms.JMSException;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Session;
+import jakarta.jms.TextMessage;
 import javax.management.MalformedObjectNameException;
 import javax.management.ObjectName;
 
@@ -56,9 +53,10 @@ import org.apache.activemq.security.SimpleAuthenticationPlugin;
 import org.apache.activemq.security.TempDestinationAuthorizationEntry;
 import org.apache.activemq.store.kahadb.KahaDBStore;
 import org.apache.activemq.util.JMXSupport;
-import org.junit.jupiter.api.AfterEach;
-import org.junit.jupiter.api.BeforeEach;
-import org.junit.jupiter.api.TestInfo;
+import org.junit.After;
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.rules.TestName;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -71,24 +69,25 @@ public class QpidJmsTestSupport {
 
     public static final String KAHADB_DIRECTORY = "target/activemq-data";
 
+    @Rule public TestName name = new TestName();
+
     protected static final Logger LOG = LoggerFactory.getLogger(QpidJmsTestSupport.class);
     protected BrokerService brokerService;
     protected final List<BrokerService> brokers = new ArrayList<BrokerService>();
     protected final Vector<Throwable> exceptions = new Vector<Throwable>();
     protected int numberOfMessages;
     protected Connection connection;
+    protected javax.jms.Connection jmsConnection;
 
-    protected String testMethodName;
-    @BeforeEach
-    public void setUp(TestInfo testInfo) throws Exception {
-        this.testMethodName = testInfo.getTestMethod().get().getName();
+    @Before
+    public void setUp() throws Exception {
         LOG.info("========== setUp " + getTestName() + " ==========");
         exceptions.clear();
         startPrimaryBroker();
         this.numberOfMessages = 2000;
     }
 
-    @AfterEach
+    @After
     public void tearDown() throws Exception {
         LOG.info("========== tearDown " + getTestName() + " ==========");
         Exception firstError = null;
@@ -102,6 +101,15 @@ public class QpidJmsTestSupport {
             }
         }
 
+        if (jmsConnection != null) {
+            try {
+                jmsConnection.close();
+            } catch (Exception e) {
+                LOG.warn("Error detected on jms connection close in tearDown: {}", e.getMessage());
+                firstError = e;
+            }
+        }
+
         try {
             stopPrimaryBroker();
         } catch (Exception e) {
@@ -124,7 +132,7 @@ public class QpidJmsTestSupport {
     }
 
     public String getDestinationName() {
-        return testMethodName;
+        return name.getMethodName();
     }
 
     public URI getBrokerActiveMQClientConnectionURI() {
@@ -280,15 +288,29 @@ public class QpidJmsTestSupport {
         return result;
     }
 
-    public Connection createActiveMQConnection() throws Exception {
+    public javax.jms.Connection createActiveMQConnection() throws Exception {
         return createActiveMQConnection(getBrokerActiveMQClientConnectionURI());
     }
 
-    public Connection createActiveMQConnection(URI brokerURI) throws Exception {
-        ConnectionFactory factory = new ActiveMQConnectionFactory(brokerURI);
+    public javax.jms.Connection createActiveMQConnection(URI brokerURI) throws Exception {
+        javax.jms.ConnectionFactory factory = new ActiveMQConnectionFactory(brokerURI);
         return factory.createConnection();
     }
 
+    public void sendMessages(javax.jms.Connection connection, javax.jms.Destination destination, int count) throws Exception {
+        javax.jms.Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+        javax.jms.MessageProducer p = session.createProducer(destination);
+
+        for (int i = 1; i <= count; i++) {
+            javax.jms.TextMessage message = session.createTextMessage();
+            message.setText("TextMessage: " + i);
+            message.setIntProperty(MESSAGE_NUMBER, i);
+            p.send(message);
+        }
+
+        session.close();
+    }
+
     public void sendMessages(Connection connection, Destination destination, int count) throws Exception {
         Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
         MessageProducer p = session.createProducer(destination);
@@ -383,17 +405,17 @@ public class QpidJmsTestSupport {
     }
 
     protected void sendToAmqQueue(int count) throws Exception {
-        Connection activemqConnection = createActiveMQConnection();
-        Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Queue amqTestQueue = amqSession.createQueue(testMethodName);
+        javax.jms.Connection activemqConnection = createActiveMQConnection();
+        javax.jms.Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+        javax.jms.Queue amqTestQueue = amqSession.createQueue(name.getMethodName());
         sendMessages(activemqConnection, amqTestQueue, count);
         activemqConnection.close();
     }
 
     protected void sendToAmqTopic(int count) throws Exception {
-        Connection activemqConnection = createActiveMQConnection();
-        Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
-        Topic amqTestTopic = amqSession.createTopic(testMethodName);
+        javax.jms.Connection activemqConnection = createActiveMQConnection();
+        javax.jms.Session amqSession = activemqConnection.createSession(false, Session.AUTO_ACKNOWLEDGE);
+        javax.jms.Topic amqTestTopic = amqSession.createTopic(name.getMethodName());
         sendMessages(activemqConnection, amqTestTopic, count);
         activemqConnection.close();
     }
@@ -482,6 +504,6 @@ public class QpidJmsTestSupport {
     }
 
     protected String getTestName() {
-        return getClass().getSimpleName() + "." + testMethodName;
+        return getClass().getSimpleName() + "." + name.getMethodName();
     }
 }
