@@ -16,31 +16,29 @@
  */
 package org.apache.qpid.jms.transactions;
 
-import static org.junit.jupiter.api.Assertions.assertEquals;
-import static org.junit.jupiter.api.Assertions.assertNotNull;
-import static org.junit.jupiter.api.Assertions.assertTrue;
-import static org.junit.jupiter.api.Assertions.fail;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
 
-import javax.jms.Destination;
-import javax.jms.Message;
-import javax.jms.MessageConsumer;
-import javax.jms.MessageProducer;
-import javax.jms.Queue;
-import javax.jms.Session;
-import javax.jms.TextMessage;
+import jakarta.jms.Destination;
+import jakarta.jms.Message;
+import jakarta.jms.MessageConsumer;
+import jakarta.jms.MessageProducer;
+import jakarta.jms.Queue;
+import jakarta.jms.Session;
+import jakarta.jms.TextMessage;
 
 import org.apache.activemq.broker.jmx.QueueViewMBean;
 import org.apache.qpid.jms.support.AmqpTestSupport;
-import org.junit.jupiter.api.Test;
-import org.junit.jupiter.api.Timeout;
+import org.junit.Test;
 
 /**
  * Basic tests for Session in Transacted mode.
  */
 public class JmsTransactedSessionTest extends AmqpTestSupport {
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCreateTxSession() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -53,8 +51,7 @@ public class JmsTransactedSessionTest extends AmqpTestSupport {
         session.close();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testCommitOnSessionWithNoWork() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -67,8 +64,7 @@ public class JmsTransactedSessionTest extends AmqpTestSupport {
         session.commit();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testRollbackOnSessionWithNoWork() throws Exception {
         connection = createAmqpConnection();
         assertNotNull(connection);
@@ -81,19 +77,18 @@ public class JmsTransactedSessionTest extends AmqpTestSupport {
         session.rollback();
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout=60000)
     public void testCloseSessionRollsBack() throws Exception {
         connection = createAmqpConnection();
         connection.start();
 
         sendToAmqQueue(2);
 
-        QueueViewMBean proxy = getProxyToQueue(testMethodName);
+        QueueViewMBean proxy = getProxyToQueue(name.getMethodName());
         assertEquals(2, proxy.getQueueSize());
 
         Session session = connection.createSession(true, Session.SESSION_TRANSACTED);
-        Queue queue = session.createQueue(testMethodName);
+        Queue queue = session.createQueue(name.getMethodName());
         MessageConsumer consumer = session.createConsumer(queue);
         Message message = consumer.receive(5000);
         assertNotNull(message);
@@ -105,14 +100,12 @@ public class JmsTransactedSessionTest extends AmqpTestSupport {
         assertEquals(2, proxy.getQueueSize());
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testRollbackSentMessagesThenConsumeWithTopic() throws Exception {
         doRollbackSentMessagesThenConsumeTestImpl(true);
     }
 
-    @Test
-    @Timeout(60)
+    @Test(timeout = 60000)
     public void testRollbackSentMessagesThenConsumeWithQueue() throws Exception {
         doRollbackSentMessagesThenConsumeTestImpl(false);
     }
